@@ -99,12 +99,14 @@ item *do_item_alloc(char *key, const size_t nkey, const int flags, const rel_tim
     /* do a quick check if we have any expired items in the tail.. */
     int tries = 50;
     item *search;
+    rel_time_t oldest_live = settings.oldest_live;
 
     for (search = tails[id];
          tries > 0 && search != NULL;
          tries--, search=search->prev) {
         if (search->refcount == 0 &&
-            (search->exptime != 0 && search->exptime < current_time)) {
+            ((search->time < oldest_live) || // dead by flush
+             (search->exptime != 0 && search->exptime < current_time))) {
             it = search;
             /* I don't want to actually free the object, just steal
              * the item to avoid to grab the slab mutex twice ;-)
@@ -114,6 +116,7 @@ item *do_item_alloc(char *key, const size_t nkey, const int flags, const rel_tim
             STATS_UNLOCK();
             itemstats[id].reclaimed++;
             it->refcount = 1;
+            slabs_adjust_mem_requested(it->slabs_clsid, ITEM_ntotal(it), ntotal);
             do_item_unlink(it);
             /* Initialize the item block: */
             it->slabs_clsid = 0;
@@ -239,8 +242,13 @@ bool item_size_ok(const size_t nkey, const int flags, const int nbytes) {
     char prefix[40];
     uint8_t nsuffix;
 
-    return slabs_clsid(item_make_header(nkey + 1, flags, nbytes,
-                                        prefix, &nsuffix)) != 0;
+    size_t ntotal = item_make_header(nkey + 1, flags, nbytes,
+                                     prefix, &nsuffix);
+    if (settings.use_cas) {
+        ntotal += sizeof(uint64_t);
+    }
+
+    return slabs_clsid(ntotal) != 0;
 }
 
 static void item_link_q(item *it) { /* item is the new head */
@@ -401,7 +409,25 @@ void do_item_stats(ADD_STAT add_stats, void *c) {
             char key_str[STAT_KEY_LEN];
             char val_str[STAT_VAL_LEN];
             int klen = 0, vlen = 0;
-
+            int search = 50;
+            while (search > 0 &&
+                   tails[i] != NULL &&
+                   ((settings.oldest_live != 0 && /* Item flushd */
+                     settings.oldest_live <= current_time &&
+                     tails[i]->time <= settings.oldest_live) ||
+                    (tails[i]->exptime != 0 && /* and not expired */
+                     tails[i]->exptime < current_time))) {
+                --search;
+                if (tails[i]->refcount == 0) {
+                    do_item_unlink(tails[i]);
+                } else {
+                    break;
+                }
+            }
+            if (tails[i] == NULL) {
+                /* We removed all of the items in this slab class */
+                continue;
+            }
             APPEND_NUM_FMT_STAT(fmt, i, "number", "%u", sizes[i]);
             APPEND_NUM_FMT_STAT(fmt, i, "age", "%u", tails[i]->time);
             APPEND_NUM_FMT_STAT(fmt, i, "evicted",
@@ -450,9 +476,7 @@ void do_item_stats_sizes(ADD_STAT add_stats, void *c) {
         for (i = 0; i < num_buckets; i++) {
             if (histogram[i] != 0) {
                 char key[8];
-                int klen = 0;
-                klen = snprintf(key, sizeof(key), "%d", i * 32);
-                assert(klen < sizeof(key));
+                snprintf(key, sizeof(key), "%d", i * 32);
                 APPEND_STAT(key, "%u", histogram[i]);
             }
         }
